@@ -127,24 +127,24 @@
 <context>
     <name>LXQt::ScreenSaver</name>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="161"/>
+        <location filename="../lxqtscreensaver.cpp" line="184"/>
         <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ezin izan da &quot;%1&quot; exekutatu. Ziurtatu xdg-pantaila-babeslearekin bateragarria den aldagela/pantaila-babeslea instalatuta eta martxan duzula.</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="165"/>
+        <location filename="../lxqtscreensaver.cpp" line="188"/>
         <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ezin izan da &quot;%1&quot; exekutatu. Ziurtatu zehaztutako aldagela/pantaila-babeslea instalatuta eta martxan dagoela.</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="243"/>
+        <location filename="../lxqtscreensaver.cpp" line="274"/>
         <source>Lock Screen</source>
         <translation>Blokeatu pantaila</translation>
     </message>
     <message>
-        <location filename="../lxqtscreensaver.cpp" line="156"/>
+        <location filename="../lxqtscreensaver.cpp" line="179"/>
         <source>Screen Saver Error</source>
-        <translation type="unfinished">Pantaila babeslearen errorea</translation>
+        <translation>Pantaila babeslearen akatsa</translation>
     </message>
 </context>
 <context>
@@ -158,20 +158,20 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
         <source>Power Manager Error</source>
         <translation>Energia-kudeatzailearen errorea</translation>
     </message>
     <message>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="89"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="139"/>
         <source>QDBusInterface is invalid</source>
         <translation>QDBusInterface baliogabea da</translation>
     </message>
     <message>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
-        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="103"/>
+        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="153"/>
         <source>Power Manager Error (D-BUS call)</source>
         <translation>Energia-kudeatzailearen errorea (D-BUS deia)</translation>
     </message>
